rel=license parsing tests

# rel=license parsing tests ‐ change logs

The files in this directory where designed to test the parsing of rel=* and xfn.

## Change log:

- Added new rel-urls test, taken from wiki mf2 parsing page ‐ 1 June 2015 by Glenn Jones
- Fixed empty JSON structure ‐ 21 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Created ‐ 11 January 2013 by Glenn Jones

## Contributors:

- Glenn Jones